# -*- coding: utf-8 -*-
# Copyright (c) 2013-2014 Simon Jagoe
# All rights reserved.
#
# This software may be modified and distributed under the terms
# of the 3-clause BSD license.  See the LICENSE.txt file for details.
import sys  # pragma: no cover

from .main import main  # pragma: no cover


if __name__ == '__main__':
    sys.exit(main())
